package com.ruoyi.traceability.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.traceability.mapper.ProMqUploadMapper;
import com.ruoyi.traceability.domain.ProMqUpload;
import com.ruoyi.traceability.service.IProMqUploadService;
import com.ruoyi.common.core.text.Convert;

/**
 * 模切数据上传Service业务层处理
 *
 * @author wenjy
 * @date 2022-11-18
 */
@Service
public class ProMqUploadServiceImpl implements IProMqUploadService
{
    @Autowired
    private ProMqUploadMapper proMqUploadMapper;

    /**
     * 查询模切数据上传
     *
     * @param id 模切数据上传主键
     * @return 模切数据上传
     */
    @Override
    public ProMqUpload selectProMqUploadById(Long id)
    {
        return proMqUploadMapper.selectProMqUploadById(id);
    }

    /**
     * 查询模切数据上传列表
     *
     * @param proMqUpload 模切数据上传
     * @return 模切数据上传
     */
    @Override
    public List<ProMqUpload> selectProMqUploadList(ProMqUpload proMqUpload)
    {
        return proMqUploadMapper.selectProMqUploadList(proMqUpload);
    }

    /**
     * 新增模切数据上传
     *
     * @param proMqUpload 模切数据上传
     * @return 结果
     */
    @Override
    public int insertProMqUpload(ProMqUpload proMqUpload)
    {
        return proMqUploadMapper.insertProMqUpload(proMqUpload);
    }

    /**
     * 修改模切数据上传
     *
     * @param proMqUpload 模切数据上传
     * @return 结果
     */
    @Override
    public int updateProMqUpload(ProMqUpload proMqUpload)
    {
        return proMqUploadMapper.updateProMqUpload(proMqUpload);
    }

    /**
     * 批量删除模切数据上传
     *
     * @param ids 需要删除的模切数据上传主键
     * @return 结果
     */
    @Override
    public int deleteProMqUploadByIds(String ids)
    {
        return proMqUploadMapper.deleteProMqUploadByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除模切数据上传信息
     *
     * @param id 模切数据上传主键
     * @return 结果
     */
    @Override
    public int deleteProMqUploadById(Long id)
    {
        return proMqUploadMapper.deleteProMqUploadById(id);
    }
}
